@@ -41,6 +41,7 @@ Whenever there is input into the fifo, the program reads the input as a list
 of URL's and creates some new easy handles to fetch each URL via the
 curl_multi "hiper" API.
 
+
 Thus, you can try a single URL:
   % echo http://www.yahoo.com > hiper.fifo
 
@@ -57,6 +58,7 @@ This is purely a demo app, all retrieved data is simply discarded by the write
 callback.
 
 */
+
 #include <errno.h>
 #include <fcntl.h>
 #include <signal.h>
@@ -75,6 +77,7 @@ callback.
 
 #define MSG_OUT stdout /* Send info to stdout, change to stderr if you want */
 
+
 /* Global information, common to all connections */
 struct GlobalInfo {
   int epfd;    /* epoll filedescriptor */
@@ -102,35 +105,23 @@ struct SockInfo {
   struct GlobalInfo *global;
 };
 
+#define mycase(code) \
+  case code: s = __STRING(code)
+
 /* Die if we get a bad CURLMcode somewhere */
 static void mcode_or_die(const char *where, CURLMcode code)
 {
   if(CURLM_OK != code) {
     const char *s;
     switch(code) {
-    case CURLM_BAD_HANDLE:
-      s = "CURLM_BAD_HANDLE";
-      break;
-    case CURLM_BAD_EASY_HANDLE:
-      s = "CURLM_BAD_EASY_HANDLE";
-      break;
-    case CURLM_OUT_OF_MEMORY:
-      s = "CURLM_OUT_OF_MEMORY";
-      break;
-    case CURLM_INTERNAL_ERROR:
-      s = "CURLM_INTERNAL_ERROR";
-      break;
-    case CURLM_UNKNOWN_OPTION:
-      s = "CURLM_UNKNOWN_OPTION";
-      break;
-    case CURLM_LAST:
-      s = "CURLM_LAST";
-      break;
-    default:
-      s = "CURLM_unknown";
-      break;
-    case CURLM_BAD_SOCKET:
-      s = "CURLM_BAD_SOCKET";
+      mycase(CURLM_BAD_HANDLE); break;
+      mycase(CURLM_BAD_EASY_HANDLE); break;
+      mycase(CURLM_OUT_OF_MEMORY); break;
+      mycase(CURLM_INTERNAL_ERROR); break;
+      mycase(CURLM_UNKNOWN_OPTION); break;
+      mycase(CURLM_LAST); break;
+      default: s = "CURLM_unknown"; break;
+      mycase(CURLM_BAD_SOCKET);
       fprintf(MSG_OUT, "ERROR: %s returns %s\n", where, s);
       /* ignore this error */
       return;
@@ -170,7 +161,7 @@ static int multi_timer_cb(CURLM *multi, long timeout_ms, struct GlobalInfo *g)
     memset(&its, 0, sizeof(its));
   }
 
-  timerfd_settime(g->tfd, /* flags= */ 0, &its, NULL);
+  timerfd_settime(g->tfd, /* flags= */0, &its, NULL);
   return 0;
 }
 
@@ -186,10 +177,10 @@ static void check_multi_info(struct GlobalInfo *g)
   while((msg = curl_multi_info_read(g->multi, &msgs_left))) {
     if(msg->msg == CURLMSG_DONE) {
       CURL *curl = msg->easy_handle;
-      CURLcode result = msg->data.result;
+      CURLcode res = msg->data.result;
       curl_easy_getinfo(curl, CURLINFO_PRIVATE, &conn);
       curl_easy_getinfo(curl, CURLINFO_EFFECTIVE_URL, &eff_url);
-      fprintf(MSG_OUT, "DONE: %s => (%d) %s\n", eff_url, result, conn->error);
+      fprintf(MSG_OUT, "DONE: %s => (%d) %s\n", eff_url, res, conn->error);
       curl_multi_remove_handle(g->multi, curl);
       free(conn->url);
       curl_easy_cleanup(curl);
@@ -201,14 +192,14 @@ static void check_multi_info(struct GlobalInfo *g)
 /* Called by libevent when we get action on a multi socket filedescriptor */
 static void event_cb(struct GlobalInfo *g, int fd, int revents)
 {
-  CURLMcode mresult;
+  CURLMcode rc;
   struct itimerspec its;
 
   int action = ((revents & EPOLLIN) ? CURL_CSELECT_IN : 0) |
-    ((revents & EPOLLOUT) ? CURL_CSELECT_OUT : 0);
+               ((revents & EPOLLOUT) ? CURL_CSELECT_OUT : 0);
 
-  mresult = curl_multi_socket_action(g->multi, fd, action, &g->still_running);
-  mcode_or_die("event_cb: curl_multi_socket_action", mresult);
+  rc = curl_multi_socket_action(g->multi, fd, action, &g->still_running);
+  mcode_or_die("event_cb: curl_multi_socket_action", rc);
 
   check_multi_info(g);
   if(g->still_running <= 0) {
@@ -221,7 +212,7 @@ static void event_cb(struct GlobalInfo *g, int fd, int revents)
 /* Called by main loop when our timeout expires */
 static void timer_cb(struct GlobalInfo *g, int revents)
 {
-  CURLMcode mresult;
+  CURLMcode rc;
   uint64_t count = 0;
   ssize_t err = 0;
 
@@ -242,9 +233,9 @@ static void timer_cb(struct GlobalInfo *g, int revents)
     perror("read(tfd)");
   }
 
-  mresult = curl_multi_socket_action(g->multi,
-                                CURL_SOCKET_TIMEOUT, 0, &g->still_running);
-  mcode_or_die("timer_cb: curl_multi_socket_action", mresult);
+  rc = curl_multi_socket_action(g->multi,
+                                  CURL_SOCKET_TIMEOUT, 0, &g->still_running);
+  mcode_or_die("timer_cb: curl_multi_socket_action", rc);
   check_multi_info(g);
 }
 
@@ -290,7 +281,7 @@ static void setsock(struct SockInfo *f, curl_socket_t s, CURL *e, int act,
 static void addsock(curl_socket_t s, CURL *curl, int action,
                     struct GlobalInfo *g)
 {
-  struct SockInfo *fdp = (struct SockInfo *)calloc(1, sizeof(struct SockInfo));
+  struct SockInfo *fdp = (struct SockInfo*)calloc(1, sizeof(struct SockInfo));
 
   fdp->global = g;
   setsock(fdp, s, curl, action, g);
@@ -300,11 +291,12 @@ static void addsock(curl_socket_t s, CURL *curl, int action,
 /* CURLMOPT_SOCKETFUNCTION */
 static int sock_cb(CURL *e, curl_socket_t s, int what, void *cbp, void *sockp)
 {
-  struct GlobalInfo *g = (struct GlobalInfo *)cbp;
-  struct SockInfo *fdp = (struct SockInfo *)sockp;
-  const char *whatstr[] = { "none", "IN", "OUT", "INOUT", "REMOVE" };
+  struct GlobalInfo *g = (struct GlobalInfo*) cbp;
+  struct SockInfo *fdp = (struct SockInfo*) sockp;
+  const char *whatstr[]={ "none", "IN", "OUT", "INOUT", "REMOVE" };
 
-  fprintf(MSG_OUT, "socket callback: s=%d e=%p what=%s ", s, e, whatstr[what]);
+  fprintf(MSG_OUT,
+          "socket callback: s=%d e=%p what=%s ", s, e, whatstr[what]);
   if(what == CURL_POLL_REMOVE) {
     fprintf(MSG_OUT, "\n");
     remsock(fdp, g);
@@ -315,7 +307,8 @@ static int sock_cb(CURL *e, curl_socket_t s, int what, void *cbp, void *sockp)
       addsock(s, e, what, g);
     }
     else {
-      fprintf(MSG_OUT, "Changing action from %s to %s\n",
+      fprintf(MSG_OUT,
+              "Changing action from %s to %s\n",
               whatstr[fdp->action], whatstr[what]);
       setsock(fdp, s, e, what, g);
     }
@@ -347,9 +340,9 @@ static int prog_cb(void *p, double dltotal, double dlnow, double ult,
 static void new_conn(const char *url, struct GlobalInfo *g)
 {
   struct ConnInfo *conn;
-  CURLMcode mresult;
+  CURLMcode rc;
 
-  conn = (struct ConnInfo *)calloc(1, sizeof(*conn));
+  conn = (struct ConnInfo*)calloc(1, sizeof(*conn));
   conn->error[0] = '\0';
 
   conn->curl = curl_easy_init();
@@ -371,10 +364,10 @@ static void new_conn(const char *url, struct GlobalInfo *g)
   curl_easy_setopt(conn->curl, CURLOPT_FOLLOWLOCATION, 1L);
   curl_easy_setopt(conn->curl, CURLOPT_LOW_SPEED_TIME, 3L);
   curl_easy_setopt(conn->curl, CURLOPT_LOW_SPEED_LIMIT, 10L);
-  fprintf(MSG_OUT, "Adding easy %p to multi %p (%s)\n",
-          conn->curl, g->multi, url);
-  mresult = curl_multi_add_handle(g->multi, conn->curl);
-  mcode_or_die("new_conn: curl_multi_add_handle", mresult);
+  fprintf(MSG_OUT,
+          "Adding easy %p to multi %p (%s)\n", conn->curl, g->multi, url);
+  rc = curl_multi_add_handle(g->multi, conn->curl);
+  mcode_or_die("new_conn: curl_multi_add_handle", rc);
 
   /* note that the add_handle() sets a timeout to trigger soon so that the
    * necessary socket_action() call gets called by this app */
@@ -388,9 +381,9 @@ static void fifo_cb(struct GlobalInfo *g, int revents)
   int n = 0;
 
   do {
-    s[0] = '\0';
+    s[0]='\0';
     rv = fscanf(g->input, "%1023s%n", s, &n);
-    s[n] = '\0';
+    s[n]='\0';
     if(n && s[0]) {
       new_conn(s, g); /* if we read a URL, go get it! */
     }
@@ -444,6 +437,7 @@ static void clean_fifo(struct GlobalInfo *g)
   unlink(fifo);
 }
 
+
 int g_should_exit_ = 0;
 
 void sigint_handler(int signo)
@@ -451,17 +445,19 @@ void sigint_handler(int signo)
   g_should_exit_ = 1;
 }
 
-int main(void)
+int main(int argc, char **argv)
 {
-  CURLcode result;
+  CURLcode res;
   struct GlobalInfo g;
   struct itimerspec its;
   struct epoll_event ev;
   struct epoll_event events[10];
+  (void)argc;
+  (void)argv;
 
-  result = curl_global_init(CURL_GLOBAL_ALL);
-  if(result)
-    return (int)result;
+  res = curl_global_init(CURL_GLOBAL_ALL);
+  if(res)
+    return (int)res;
 
   g_should_exit_ = 0;
   signal(SIGINT, sigint_handler);
@@ -510,7 +506,7 @@ int main(void)
   while(!g_should_exit_) {
     int idx;
     int err = epoll_wait(g.epfd, events,
-                         sizeof(events) / sizeof(struct epoll_event), 10000);
+                         sizeof(events)/sizeof(struct epoll_event), 10000);
     if(err == -1) {
       /* !checksrc! disable ERRNOVAR 1 */
       if(errno == EINTR) {
