@@ -27,14 +27,14 @@
  */
 #include <stdio.h>
 #include <fcntl.h>
-#include <sys/stat.h>
+
 #include <curl/curl.h>
 
 static const char olivertwist[]=
   "Among other public buildings in a certain town, which for many reasons "
   "it will be prudent to refrain from mentioning, and to which I will assign "
   "no fictitious name, there is one anciently common to most towns, great or "
-  "small: to wit, a workhouse; and in this workhouse was born; on a day and "
+  "small: to ___, a workhouse; and in this workhouse was born; on a day and "
   "date which I need not trouble myself to repeat, inasmuch as it can be of "
   "no possible consequence to the reader, in this stage of the business at "
   "all events; the item of mortality whose name is prefixed";
@@ -58,8 +58,10 @@ int main(int argc, char **argv)
 
   url = argv[1];
 
-  /* In windows, this inits the winsock stuff */
-  curl_global_init(CURL_GLOBAL_ALL);
+  /* In Windows, this inits the Winsock stuff */
+  res = curl_global_init(CURL_GLOBAL_ALL);
+  if(res)
+    return (int)res;
 
   /* get a curl handle */
   curl = curl_easy_init();
@@ -101,5 +103,5 @@ int main(int argc, char **argv)
   }
 
   curl_global_cleanup();
-  return 0;
+  return (int)res;
 }
