@@ -21,10 +21,14 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-#include "curl_setup.h"
 
+#include "curl_setup.h"
 #include "uint-bset.h"
 
+/* The last 2 #include files should be in this order */
+#include "curl_memory.h"
+#include "memdebug.h"
+
 #ifdef DEBUGBUILD
 #define CURL_UINT32_BSET_MAGIC  0x62757473
 #endif
@@ -37,21 +41,22 @@ void Curl_uint32_bset_init(struct uint32_bset *bset)
 #endif
 }
 
+
 CURLcode Curl_uint32_bset_resize(struct uint32_bset *bset, uint32_t nmax)
 {
-  uint32_t nslots = (nmax < (UINT32_MAX - 63)) ?
+  uint32_t nslots = (nmax < (UINT32_MAX-63)) ?
                     ((nmax + 63) / 64) : (UINT32_MAX / 64);
 
   DEBUGASSERT(bset->init == CURL_UINT32_BSET_MAGIC);
   if(nslots != bset->nslots) {
-    uint64_t *slots = curlx_calloc(nslots, sizeof(uint64_t));
+    uint64_t *slots = calloc(nslots, sizeof(uint64_t));
     if(!slots)
       return CURLE_OUT_OF_MEMORY;
 
     if(bset->slots) {
       memcpy(slots, bset->slots,
              (CURLMIN(nslots, bset->nslots) * sizeof(uint64_t)));
-      curlx_free(bset->slots);
+      free(bset->slots);
     }
     bset->slots = slots;
     bset->nslots = nslots;
@@ -60,10 +65,11 @@ CURLcode Curl_uint32_bset_resize(struct uint32_bset *bset, uint32_t nmax)
   return CURLE_OK;
 }
 
+
 void Curl_uint32_bset_destroy(struct uint32_bset *bset)
 {
   DEBUGASSERT(bset->init == CURL_UINT32_BSET_MAGIC);
-  curlx_free(bset->slots);
+  free(bset->slots);
   memset(bset, 0, sizeof(*bset));
 }
 
@@ -95,6 +101,7 @@ bool Curl_uint32_bset_empty(struct uint32_bset *bset)
   return TRUE;
 }
 
+
 void Curl_uint32_bset_clear(struct uint32_bset *bset)
 {
   if(bset->nslots) {
@@ -103,6 +110,7 @@ void Curl_uint32_bset_clear(struct uint32_bset *bset)
   }
 }
 
+
 bool Curl_uint32_bset_add(struct uint32_bset *bset, uint32_t i)
 {
   uint32_t islot = i / 64;
@@ -114,6 +122,7 @@ bool Curl_uint32_bset_add(struct uint32_bset *bset, uint32_t i)
   return TRUE;
 }
 
+
 void Curl_uint32_bset_remove(struct uint32_bset *bset, uint32_t i)
 {
   size_t islot = i / 64;
@@ -121,6 +130,7 @@ void Curl_uint32_bset_remove(struct uint32_bset *bset, uint32_t i)
     bset->slots[islot] &= ~((uint64_t)1 << (i % 64));
 }
 
+
 bool Curl_uint32_bset_contains(struct uint32_bset *bset, uint32_t i)
 {
   uint32_t islot = i / 64;
@@ -129,6 +139,7 @@ bool Curl_uint32_bset_contains(struct uint32_bset *bset, uint32_t i)
   return (bset->slots[islot] & ((uint64_t)1 << (i % 64))) != 0;
 }
 
+
 bool Curl_uint32_bset_first(struct uint32_bset *bset, uint32_t *pfirst)
 {
   uint32_t i;
@@ -185,12 +196,13 @@ uint32_t Curl_popcount64(uint64_t x)
   x -= (x >> 1) & m1;             /* replace every 2 bits with bits present */
   x = (x & m2) + ((x >> 2) & m2); /* replace every nibble with bits present */
   x = (x + (x >> 4)) & m4;        /* replace every byte with bits present */
-  /* top 8 bits of x + (x << 8) + (x << 16) + (x << 24) + ... which makes the
+  /* top 8 bits of x + (x<<8) + (x<<16) + (x<<24) + ... which makes the
    * top byte the sum of all individual 8 bytes, throw away the rest */
   return (uint32_t)((x * h01) >> 56);
 }
 #endif /* CURL_POPCOUNT64_IMPLEMENT */
 
+
 #ifdef CURL_CTZ64_IMPLEMENT
 uint32_t Curl_ctz64(uint64_t x)
 {
