@@ -55,8 +55,8 @@ int tool_seek_cb(void *userdata, curl_off_t offset, int whence)
 
   if(offset > OUR_MAX_SEEK_O) {
     /* Some precaution code to work around problems with different data sizes
-       to allow seeking >32-bit even if off_t is 32-bit. Should be very rare
-       and is really valid on weirdo-systems. */
+       to allow seeking >32-bit even if off_t is 32-bit. Should be rare and
+       is really valid on weirdo-systems. */
     curl_off_t left = offset;
 
     if(whence != SEEK_SET)
@@ -78,7 +78,7 @@ int tool_seek_cb(void *userdata, curl_off_t offset, int whence)
   }
 #endif
 
-#if defined(__AMIGA__) || defined(__MINGW32CE__)
+#ifdef __AMIGA__
   if(LSEEK_ERROR == lseek(per->infd, (off_t)offset, whence))
 #else
   if(LSEEK_ERROR == lseek(per->infd, offset, whence))
