@@ -30,6 +30,8 @@
 #include "tool_ssls.h"
 #include "tool_parsecfg.h"
 
+#include "memdebug.h" /* keep this as LAST include */
+
 /* The maximum line length for an ecoded session ticket */
 #define MAX_SSLS_LINE (64 * 1024)
 
@@ -80,8 +82,8 @@ CURLcode tool_ssls_load(struct OperationConfig *config,
   i = imported = 0;
   while(my_get_line(fp, &buf, &error)) {
     ++i;
-    curl_free(shmac);
-    curl_free(sdata);
+    tool_safefree(shmac);
+    tool_safefree(sdata);
     line = curlx_dyn_ptr(&buf);
 
     c = memchr(line, ':', strlen(line));
@@ -125,8 +127,8 @@ out:
   if(fp)
     curlx_fclose(fp);
   curlx_dyn_free(&buf);
-  curl_free(shmac);
-  curl_free(sdata);
+  free(shmac);
+  free(sdata);
   return r;
 }
 
@@ -154,10 +156,10 @@ static CURLcode tool_ssls_exp(CURL *easy, void *userptr,
   (void)earlydata_max;
   if(!ctx->exported)
     fputs("# Your SSL session cache. https://curl.se/docs/ssl-sessions.html\n"
-        "# This file was generated by libcurl! Edit at your own risk.\n",
-        ctx->fp);
+          "# This file was generated by libcurl! Edit at your own risk.\n",
+          ctx->fp);
 
-  r = curlx_base64_encode((const char *)shmac, shmac_len, &enc, &enc_len);
+  r = curlx_base64_encode(shmac, shmac_len, &enc, &enc_len);
   if(r)
     goto out;
   r = CURLE_WRITE_ERROR;
@@ -165,8 +167,8 @@ static CURLcode tool_ssls_exp(CURL *easy, void *userptr,
     goto out;
   if(EOF == fputc(':', ctx->fp))
     goto out;
-  curl_free(enc);
-  r = curlx_base64_encode((const char *)sdata, sdata_len, &enc, &enc_len);
+  tool_safefree(enc);
+  r = curlx_base64_encode(sdata, sdata_len, &enc, &enc_len);
   if(r)
     goto out;
   r = CURLE_WRITE_ERROR;
@@ -179,7 +181,7 @@ static CURLcode tool_ssls_exp(CURL *easy, void *userptr,
 out:
   if(r)
     warnf("Warning: error saving SSL session for '%s': %d", session_key, r);
-  curl_free(enc);
+  free(enc);
   return r;
 }
 
