@@ -25,12 +25,25 @@
 
 #include "memdebug.h"
 
-size_t WriteOutput(char *ptr, size_t size, size_t nmemb, void *stream);
-size_t WriteHeader(char *ptr, size_t size, size_t nmemb, void *stream);
+static size_t realHeaderSize = 0;
 
-static unsigned long realHeaderSize = 0;
+static size_t WriteOutput(char *ptr, size_t size, size_t nmemb, void *stream)
+{
+  fwrite(ptr, size, nmemb, stream);
+  return nmemb * size;
+}
 
-static CURLcode test_lib1509(char *URL)
+static size_t WriteHeader(char *ptr, size_t size, size_t nmemb, void *stream)
+{
+  (void)ptr;
+  (void)stream;
+
+  realHeaderSize += size * nmemb;
+
+  return nmemb * size;
+}
+
+static CURLcode test_lib1509(const char *URL)
 {
   long headerSize;
   CURLcode code;
@@ -43,8 +56,8 @@ static CURLcode test_lib1509(char *URL)
 
   easy_setopt(curl, CURLOPT_PROXY, libtest_arg2); /* set in first.c */
 
-  easy_setopt(curl, CURLOPT_WRITEFUNCTION, *WriteOutput);
-  easy_setopt(curl, CURLOPT_HEADERFUNCTION, *WriteHeader);
+  easy_setopt(curl, CURLOPT_WRITEFUNCTION, WriteOutput);
+  easy_setopt(curl, CURLOPT_HEADERFUNCTION, WriteHeader);
 
   easy_setopt(curl, CURLOPT_HEADER, 1L);
   easy_setopt(curl, CURLOPT_VERBOSE, 1L);
@@ -70,7 +83,7 @@ static CURLcode test_lib1509(char *URL)
   }
 
   curl_mprintf("header length is ........: %ld\n", headerSize);
-  curl_mprintf("header length should be..: %lu\n", realHeaderSize);
+  curl_mprintf("header length should be..: %zu\n", realHeaderSize);
 
 test_cleanup:
 
@@ -79,19 +92,3 @@ test_cleanup:
 
   return res;
 }
-
-size_t WriteOutput(char *ptr, size_t size, size_t nmemb, void *stream)
-{
-  fwrite(ptr, size, nmemb, stream);
-  return nmemb * size;
-}
-
-size_t WriteHeader(char *ptr, size_t size, size_t nmemb, void *stream)
-{
-  (void)ptr;
-  (void)stream;
-
-  realHeaderSize += curlx_uztoul(size * nmemb);
-
-  return nmemb * size;
-}
