@@ -27,9 +27,15 @@
 
 static CURLcode test_lib1568(const char *URL)
 {
-  CURLcode ret;
+  CURLcode res = TEST_ERR_MAJOR_BAD;
   CURL *curl;
-  curl_global_init(CURL_GLOBAL_ALL);
+  curl_off_t port;
+
+  if(curlx_str_number(&libtest_arg2, &port, 0xffff))
+    return res;
+
+  if(curl_global_init(CURL_GLOBAL_ALL) != CURLE_OK)
+    return res;
 
   curl = curl_easy_init();
   curl_easy_setopt(curl, CURLOPT_URL, URL);
@@ -39,13 +45,12 @@ static CURLcode test_lib1568(const char *URL)
   curl_easy_setopt(curl, CURLOPT_USERAGENT, "lib1568");
   curl_easy_setopt(curl, CURLOPT_HTTPAUTH, CURLAUTH_DIGEST);
   curl_easy_setopt(curl, CURLOPT_MAXREDIRS, 50L);
-  curl_easy_setopt(curl, CURLOPT_PORT, atol(libtest_arg2));
+  curl_easy_setopt(curl, CURLOPT_PORT, (long)port);
 
-  ret = curl_easy_perform(curl);
+  res = curl_easy_perform(curl);
 
   curl_easy_cleanup(curl);
-  curl = NULL;
 
   curl_global_cleanup();
-  return ret;
+  return res;
 }
