@@ -23,9 +23,11 @@
  ***************************************************************************/
 #include "first.h"
 
+#include "memdebug.h"
+
 static CURLcode test_lib556(const char *URL)
 {
-  CURLcode result;
+  CURLcode res;
   CURL *curl;
   int transfers = 0;
 
@@ -47,9 +49,9 @@ static CURLcode test_lib556(const char *URL)
 
 again:
 
-  result = curl_easy_perform(curl);
+  res = curl_easy_perform(curl);
 
-  if(!result) {
+  if(!res) {
     /* we are connected, now get an HTTP document the raw way */
     char request[64];
     const char *sbuf = request;
@@ -64,8 +66,8 @@ again:
       char buf[1024];
 
       if(sblen) {
-        result = curl_easy_send(curl, sbuf, sblen, &nwritten);
-        if(result && result != CURLE_AGAIN)
+        res = curl_easy_send(curl, sbuf, sblen, &nwritten);
+        if(res && res != CURLE_AGAIN)
           break;
         if(nwritten > 0) {
           sbuf += nwritten;
@@ -74,7 +76,7 @@ again:
       }
 
       /* busy-read like crazy */
-      result = curl_easy_recv(curl, buf, sizeof(buf), &nread);
+      res = curl_easy_recv(curl, buf, sizeof(buf), &nread);
 
       if(nread) {
         /* send received stuff to stdout */
@@ -82,21 +84,21 @@ again:
           char errbuf[STRERROR_LEN];
           curl_mfprintf(stderr, "write() failed: errno %d (%s)\n",
                         errno, curlx_strerror(errno, errbuf, sizeof(errbuf)));
-          result = TEST_ERR_FAILURE;
+          res = TEST_ERR_FAILURE;
           break;
         }
       }
 
-    } while((result == CURLE_OK && nread) || (result == CURLE_AGAIN));
+    } while((res == CURLE_OK && nread) || (res == CURLE_AGAIN));
 
-    if(result && result != CURLE_AGAIN)
-      result = TEST_ERR_FAILURE;
+    if(res && res != CURLE_AGAIN)
+      res = TEST_ERR_FAILURE;
   }
 
   if(testnum == 696) {
     ++transfers;
     /* perform the transfer a second time */
-    if(!result && transfers == 1)
+    if(!res && transfers == 1)
       goto again;
   }
 
@@ -105,5 +107,5 @@ test_cleanup:
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return result;
+  return res;
 }
