@@ -53,10 +53,10 @@ static size_t t643_read_cb(char *ptr, size_t size, size_t nmemb, void *userp)
     return 1;                        /* we return 1 byte at a time! */
   }
 
-  return 0;                         /* no more data left to deliver */
+  return 0;                          /* no more data left to deliver */
 }
 
-static CURLcode t643_test_once(char *URL, bool oldstyle)
+static CURLcode t643_test_once(const char *URL, bool oldstyle)
 {
   static const char testdata[] = "dummy\n";
 
@@ -114,7 +114,7 @@ static CURLcode t643_test_once(char *URL, bool oldstyle)
       res = curl_mime_data_cb(part, datasize, t643_read_cb,
                               NULL, NULL, &pooh);
     if(!res)
-      res = curl_mime_filename(part, "file name 2");
+      res = curl_mime_filename(part, "filename 2 ");
   }
 
   if(res)
@@ -225,13 +225,13 @@ test_cleanup:
 
 static CURLcode t643_cyclic_add(void)
 {
-  CURL *easy = curl_easy_init();
-  curl_mime *mime = curl_mime_init(easy);
+  CURL *curl = curl_easy_init();
+  curl_mime *mime = curl_mime_init(curl);
   curl_mimepart *part = curl_mime_addpart(mime);
   CURLcode a1 = curl_mime_subparts(part, mime);
 
   if(a1 == CURLE_BAD_FUNCTION_ARGUMENT) {
-    curl_mime *submime = curl_mime_init(easy);
+    curl_mime *submime = curl_mime_init(curl);
     curl_mimepart *subpart = curl_mime_addpart(submime);
 
     curl_mime_subparts(part, submime);
@@ -239,7 +239,7 @@ static CURLcode t643_cyclic_add(void)
   }
 
   curl_mime_free(mime);
-  curl_easy_cleanup(easy);
+  curl_easy_cleanup(curl);
   if(a1 != CURLE_BAD_FUNCTION_ARGUMENT)
     /* that should have failed */
     return TEST_ERR_FAILURE;
@@ -247,7 +247,7 @@ static CURLcode t643_cyclic_add(void)
   return CURLE_OK;
 }
 
-static CURLcode test_lib643(char *URL)
+static CURLcode test_lib643(const char *URL)
 {
   CURLcode res;
 
